#[repr(C)]pub struct Size {
pub width: i32,
pub height: i32,
}Expand description
The integer dimensions of a rectangular region in a 2D cartesian space.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
This type allows for negative dimensions, to which protocols can give semantics. Protocols that use this type should specify whether negative dimensions are meaningful, and, if they are meaningful, what they mean.
Fields
width: i32height: i32Trait Implementations
Sourceimpl<'a, ___E> Encode<Size, ___E> for &'a Sizewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Size, ___E> for &'a Sizewhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Size, ___E> for Sizewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Size, ___E> for Sizewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Size, Size>
const COPY_OPTIMIZATION: CopyOptimization<Size, Size>
Sourceimpl FromWireRef<Size> for Size
impl FromWireRef<Size> for Size
Sourcefn from_wire_ref(wire: &Size) -> Size
fn from_wire_ref(wire: &Size) -> Size
Converts the given reference to this type.
Sourceimpl Ord for Size
impl Ord for Size
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Size
impl PartialOrd for Size
impl Copy for Size
impl Eq for Size
impl StructuralPartialEq for Size