#[repr(C)]pub struct SizeF {
pub width: f32,
pub height: f32,
}Expand description
The floating point dimensions of a rectangular region in a 2D cartesian space.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
This type allows for negative dimensions, to which protocols can give semantics. Protocols that use this type should specify whether negative dimensions are meaningful, and, if they are meaningful, what they mean.
Fields
width: f32height: f32Trait Implementations
Sourceimpl<'a, ___E> Encode<SizeF, ___E> for &'a SizeFwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SizeF, ___E> for &'a SizeFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<SizeF, ___E> for SizeFwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SizeF, ___E> for SizeFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SizeF, SizeF>
const COPY_OPTIMIZATION: CopyOptimization<SizeF, SizeF>
Sourceimpl FromWireRef<SizeF> for SizeF
impl FromWireRef<SizeF> for SizeF
Sourcefn from_wire_ref(wire: &SizeF) -> SizeF
fn from_wire_ref(wire: &SizeF) -> SizeF
Converts the given reference to this type.
Sourceimpl PartialOrd for SizeF
impl PartialOrd for SizeF
impl Copy for SizeF
impl StructuralPartialEq for SizeF