#[repr(C)]pub struct Vec3F {
pub x: f32,
pub y: f32,
pub z: f32,
}Expand description
Represents a 3D vector with floating point coordinates.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
x: f32y: f32z: f32Trait Implementations
Sourceimpl<'a, ___E> Encode<Vec3F, ___E> for &'a Vec3Fwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Vec3F, ___E> for &'a Vec3Fwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Vec3F, ___E> for Vec3Fwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Vec3F, ___E> for Vec3Fwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Vec3F, Vec3F>
const COPY_OPTIMIZATION: CopyOptimization<Vec3F, Vec3F>
Sourceimpl FromWireRef<Vec3F> for Vec3F
impl FromWireRef<Vec3F> for Vec3F
Sourcefn from_wire_ref(wire: &Vec3F) -> Vec3F
fn from_wire_ref(wire: &Vec3F) -> Vec3F
Converts the given reference to this type.
Sourceimpl PartialOrd for Vec3F
impl PartialOrd for Vec3F
impl Copy for Vec3F
impl StructuralPartialEq for Vec3F