#[repr(C)]pub struct Rect {
pub x: i32,
pub y: i32,
pub width: i32,
pub height: i32,
}Expand description
An integral, rectangular, axis-aligned region in a 2D cartesian space.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
x: i32y: i32width: i32height: i32Trait Implementations
Sourceimpl<'a, ___E> Encode<Rect, ___E> for &'a Rectwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Rect, ___E> for &'a Rectwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Rect, ___E> for Rectwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Rect, ___E> for Rectwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Rect, Rect>
const COPY_OPTIMIZATION: CopyOptimization<Rect, Rect>
Sourceimpl FromWireRef<Rect> for Rect
impl FromWireRef<Rect> for Rect
Sourcefn from_wire_ref(wire: &Rect) -> Rect
fn from_wire_ref(wire: &Rect) -> Rect
Converts the given reference to this type.
Sourceimpl Ord for Rect
impl Ord for Rect
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Rect
impl PartialOrd for Rect
impl Copy for Rect
impl Eq for Rect
impl StructuralPartialEq for Rect