#[repr(C)]pub struct RectF {
pub x: f32,
pub y: f32,
pub width: f32,
pub height: f32,
}Expand description
A floating point, rectangular, axis-aligned region in a 2D cartesian space.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
x: f32y: f32width: f32height: f32Trait Implementations
Sourceimpl<'a, ___E> Encode<RectF, ___E> for &'a RectFwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<RectF, ___E> for &'a RectFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<RectF, ___E> for RectFwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<RectF, ___E> for RectFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<RectF, RectF>
const COPY_OPTIMIZATION: CopyOptimization<RectF, RectF>
Sourceimpl FromWireRef<RectF> for RectF
impl FromWireRef<RectF> for RectF
Sourcefn from_wire_ref(wire: &RectF) -> RectF
fn from_wire_ref(wire: &RectF) -> RectF
Converts the given reference to this type.
Sourceimpl PartialOrd for RectF
impl PartialOrd for RectF
impl Copy for RectF
impl StructuralPartialEq for RectF