RectU

Struct RectU 

#[repr(C)]
pub struct RectU { pub x: u32, pub y: u32, pub width: u32, pub height: u32, }
An integral, rectangular, axis-aligned region in a 2D cartesian space, with unsigned location and distance fields.

This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.

Fields

x: u32y: u32width: u32height: u32