#[repr(C)]pub struct Vec {
pub x: i32,
pub y: i32,
}Expand description
Represents a 2D vector with integer coordinates.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
x: i32y: i32Trait Implementations
Sourceimpl<'a, ___E> Encode<Vec, ___E> for &'a Vecwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Vec, ___E> for &'a Vecwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Vec, ___E> for Vecwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Vec, ___E> for Vecwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Vec, Vec>
const COPY_OPTIMIZATION: CopyOptimization<Vec, Vec>
Sourceimpl FromWireRef<Vec> for Vec
impl FromWireRef<Vec> for Vec
Sourcefn from_wire_ref(wire: &Vec) -> Vec
fn from_wire_ref(wire: &Vec) -> Vec
Converts the given reference to this type.
Sourceimpl Ord for Vec
impl Ord for Vec
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Vec
impl PartialOrd for Vec
impl Copy for Vec
impl Eq for Vec
impl StructuralPartialEq for Vec