#[repr(C)]pub struct RectU {
pub x: u32,
pub y: u32,
pub width: u32,
pub height: u32,
}Expand description
An integral, rectangular, axis-aligned region in a 2D cartesian space, with unsigned location and distance fields.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
x: u32y: u32width: u32height: u32Trait Implementations
Sourceimpl<'a, ___E> Encode<RectU, ___E> for &'a RectUwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<RectU, ___E> for &'a RectUwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<RectU, ___E> for RectUwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<RectU, ___E> for RectUwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<RectU, RectU>
const COPY_OPTIMIZATION: CopyOptimization<RectU, RectU>
Sourceimpl FromWireRef<RectU> for RectU
impl FromWireRef<RectU> for RectU
Sourcefn from_wire_ref(wire: &RectU) -> RectU
fn from_wire_ref(wire: &RectU) -> RectU
Converts the given reference to this type.
Sourceimpl Ord for RectU
impl Ord for RectU
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for RectU
impl PartialOrd for RectU
impl Copy for RectU
impl Eq for RectU
impl StructuralPartialEq for RectU